@@ -2,9 +2,7 @@ use strict;
 use warnings;
 
 package App::Cmd::Command;
-{
-  $App::Cmd::Command::VERSION = '0.322';
-}
+$App::Cmd::Command::VERSION = '0.325';
 use App::Cmd::ArgProcessor;
 BEGIN { our @ISA = 'App::Cmd::ArgProcessor' };
 
@@ -12,6 +10,19 @@ BEGIN { our @ISA = 'App::Cmd::ArgProcessor' };
 
 use Carp ();
 
+#pod =method prepare
+#pod
+#pod   my ($cmd, $opt, $args) = $class->prepare($app, @args);
+#pod
+#pod This method is the primary way in which App::Cmd::Command objects are built.
+#pod Given the remaining command line arguments meant for the command, it returns
+#pod the Command object, parsed options (as a hashref), and remaining arguments (as
+#pod an arrayref).
+#pod
+#pod In the usage above, C<$app> is the App::Cmd object that is invoking the
+#pod command.
+#pod
+#pod =cut
 
 sub prepare {
   my ($class, $app, @args) = @_;
@@ -35,12 +46,30 @@ sub _option_processing_params {
   );
 }
 
+#pod =method new
+#pod
+#pod This returns a new instance of the command plugin.  Probably only C<prepare>
+#pod should use this.
+#pod
+#pod =cut
 
 sub new {
   my ($class, $arg) = @_;
   bless $arg => $class;
 }
 
+#pod =method execute
+#pod
+#pod   $command_plugin->execute(\%opt, \@args);
+#pod
+#pod This method does whatever it is the command should do!  It is passed a hash
+#pod reference of the parsed command-line options and an array reference of left
+#pod over arguments.
+#pod
+#pod If no C<execute> method is defined, it will try to call C<run> -- but it will
+#pod warn about this behavior during testing, to remind you to fix the method name!
+#pod
+#pod =cut
 
 sub execute {
   my $class = shift;
@@ -55,12 +84,37 @@ sub execute {
   Carp::croak ref($class) . " does not implement mandatory method 'execute'\n";
 }
 
+#pod =method app
+#pod
+#pod This method returns the App::Cmd object into which this command is plugged.
+#pod
+#pod =cut
 
 sub app { $_[0]->{app}; }
 
+#pod =method usage
+#pod
+#pod This method returns the usage object for this command.  (See
+#pod L<Getopt::Long::Descriptive>).
+#pod
+#pod =cut
 
 sub usage { $_[0]->{usage}; }
 
+#pod =method command_names
+#pod
+#pod This method returns a list of command names handled by this plugin. The
+#pod first item returned is the 'canonical' name of the command.
+#pod
+#pod If this method is not overridden by an App::Cmd::Command subclass, it will
+#pod return the last part of the plugin's package name, converted to lowercase.
+#pod For example, YourApp::Cmd::Command::Init will, by default, handle the command
+#pod "init".
+#pod
+#pod Subclasses should generally get the superclass value of C<command_names>
+#pod and then append aliases.
+#pod
+#pod =cut
 
 sub command_names {
   # from UNIVERSAL::moniker
@@ -68,6 +122,15 @@ sub command_names {
   return lc $1;
 }
 
+#pod =method usage_desc
+#pod
+#pod This method should be overridden to provide a usage string.  (This is the first
+#pod argument passed to C<describe_options> from Getopt::Long::Descriptive.)
+#pod
+#pod If not overridden, it returns "%c COMMAND %o";  COMMAND is the first item in
+#pod the result of the C<command_names> method.
+#pod
+#pod =cut
 
 sub usage_desc {
   my ($self) = @_;
@@ -76,14 +139,41 @@ sub usage_desc {
   return "%c $command %o"
 }
 
+#pod =method opt_spec
+#pod
+#pod This method should be overridden to provide option specifications.  (This is
+#pod list of arguments passed to C<describe_options> from Getopt::Long::Descriptive,
+#pod after the first.)
+#pod
+#pod If not overridden, it returns an empty list.
+#pod
+#pod =cut
 
 sub opt_spec {
   return;
 }
 
+#pod =method validate_args
+#pod
+#pod   $command_plugin->validate_args(\%opt, \@args);
+#pod
+#pod This method is passed a hashref of command line options (as processed by
+#pod Getopt::Long::Descriptive) and an arrayref of leftover arguments.  It may throw
+#pod an exception (preferably by calling C<usage_error>, below) if they are invalid,
+#pod or it may do nothing to allow processing to continue.
+#pod
+#pod =cut
 
 sub validate_args { }
 
+#pod =method usage_error
+#pod
+#pod   $self->usage_error("This command must not be run by root!");
+#pod
+#pod This method should be called to die with human-friendly usage output, during
+#pod C<validate_args>.
+#pod
+#pod =cut
 
 sub usage_error {
   my ( $self, $error ) = @_;
@@ -96,6 +186,14 @@ sub _usage_text {
   join "\n", eval { $self->app->_usage_text }, eval { $self->usage->text };
 }
 
+#pod =method abstract
+#pod
+#pod This method returns a short description of the command's purpose.  If this
+#pod method is not overridden, it will return the abstract from the module's Pod.
+#pod If it can't find the abstract, it will look for a comment starting with
+#pod "ABSTRACT:" like the ones used by L<Pod::Weaver::Section::Name>.
+#pod
+#pod =cut
 
 # stolen from ExtUtils::MakeMaker
 sub abstract {
@@ -108,7 +206,7 @@ sub abstract {
   # classname to filename
   (my $pm_file = $class) =~ s!::!/!g;
   $pm_file .= '.pm';
-  $pm_file = $INC{$pm_file};
+  $pm_file = $INC{$pm_file} or return "(unknown)";
 
   # if the pm file exists, open it and parse it
   open my $fh, "<", $pm_file or return "(unknown)";
@@ -137,6 +235,14 @@ sub abstract {
   return $result || $weaver_abstract || "(unknown)";
 }
 
+#pod =method description
+#pod
+#pod This method should be overridden to provide full option description. It
+#pod is used by the built-in L<help|App::Cmd::Command::help> command.
+#pod
+#pod If not overridden, it returns an empty string.
+#pod
+#pod =cut
 
 sub description { '' }
 
@@ -146,13 +252,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 App::Cmd::Command - a base class for App::Cmd commands
 
 =head1 VERSION
 
-version 0.322
+version 0.325
 
 =head1 METHODS
 
@@ -258,7 +366,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2014 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
